@@ -42,6 +42,6 @@ def timeout_tracking(func):
         res = func(*argv, **kwgs)
         proc_time = int((time.time() - start_time) * 1000)
         msg = get_latency_msg_for_millisecond(proc_time, func.__name__)
-        print(msg)
+        print("[TIMEOUT]".format(msg))
         return res
     return wrapper
